==> defichain-1.2.0.tar.gz: defichain-1.2.0/README.md <==
[![PyPI Version](https://img.shields.io/pypi/v/defichain.svg?color=green)](https://pypi.org/project/defichain)
[![PyPI Python Version](https://img.shields.io/pypi/pyversions/defichain.svg)](https://pypi.org/project/defichain)
[![Documentation Status](https://readthedocs.org/projects/pytest/badge/?version=latest)](https://docs.defichain-python.de/)
[![Downloads](https://static.pepy.tech/personalized-badge/defichain?period=total&units=international_system&left_color=grey&right_color=green&left_text=Downloads)](https://pepy.tech/project/defichain)

# [DefichainPython](https://github.com/eric-volz/DefichainPython)

## Welcome to Defichain's Python Library

Welcome to the Python Library for the Defichain! 

In this library all RPC commands of a [Defichain Node](https://defichain.com/downloads) are available and can be 
called in a few lines of code!

If you just want to query data from the blockchain you can also use the Ocean API: you don't need a Defichain Node for 
this, just an internet connection!

## What are you looking for?

1. If you don't have a Defichain node yet, here's how to set one up: [Install Defichain Node](https://docs.defichain-python.de/build/html/additionalInfos/installDefichainNode.html)

2. If you are looking for a quick way to get started with the library, check out the [Quickstart](https://docs.defichain-python.de/build/html/instructions/quickstart.html) section.

3. If you want to look at the documentation of each method: For [Node / RPC](https://docs.defichain-python.de/build/html/api/node/index.html)
   | For [Ocean](https://docs.defichain-python.de/build/html/api/ocean/index.html)

## Progress and Updates
If you want to view the progress of the project, look here: [Progress and Updates](https://docs.defichain-python.de/build/html/instructions/progressAndUpdates.html)

## [Community](https://docs.defichain-python.de/build/html/legal/community.html)

This [project](https://github.com/DeFiCh/dfips/issues/133) is funded by the Defichain Community:
Thank you for your trust! If you have suggestions for improvement
or other ideas open an [issue](https://github.com/eric-volz/DefichainPython/issues), 
write me on [Twitter](https://twitter.com/Intr0c) or via email (introc@volz.link)!

## [License & Disclaimer](https://docs.defichain-python.de/build/html/legal/licenseAndDisclaimer.html)

By using (this repo), you (the user) agree to be bound by the 
[terms of this license](https://github.com/eric-volz/defichainLibrary/blob/main/LICENSE) (MIT License).

==> defichain-2.0.0a0.tar.gz: defichain-2.0.0a0/README.md <==
[![PyPI Version](https://img.shields.io/pypi/v/defichain.svg?color=green)](https://pypi.org/project/defichain)
[![PyPI Python Version](https://img.shields.io/pypi/pyversions/defichain.svg)](https://pypi.org/project/defichain)
[![Documentation Status](https://readthedocs.org/projects/pytest/badge/?version=latest)](https://docs.defichain-python.de/)
[![Downloads](https://static.pepy.tech/personalized-badge/defichain?period=total&units=international_system&left_color=grey&right_color=green&left_text=Downloads)](https://pepy.tech/project/defichain)

# [DefichainPython](https://github.com/eric-volz/DefichainPython)

## Welcome to Defichain's Python Library

Welcome to the Python Library for the Defichain!

This is a community funded project to make it easier for the user to communicate with the defichain blockchain.

There are currently three use cases of this Library: 

1. Easy and seamless connection to a defichain node via python: [Node / RPC](https://docs.defichain-python.de/build/html/api/node/index.html)
2. Easy to use Ocean integration to query data from the blockchain: [Ocean](https://docs.defichain-python.de/build/html/api/ocean/index.html)
3. A simple way to calculate all addresses and private keys truth a wallet integration: [HDWallet](https://docs.defichain-python.de/build/html/api/hdwallet/index.html)

## Installation

Download the PyPi package:
```
pip install defichain -U
```
Clone the GitHub Repository:
```
git clone https://github.com/eric-volz/DefichainPython.git
```

If you want to get started quick, read the [Quickstart](https://docs.defichain-python.de/build/html/instructions/quickstart.html) guide to get an overview of the library.

## Progress and Updates
If you want to view the progress of the project, look here: [Progress and Updates](https://docs.defichain-python.de/build/html/instructions/progressAndUpdates.html)

## [Community](https://docs.defichain-python.de/build/html/legal/community.html)

This [project](https://github.com/DeFiCh/dfips/issues/133) is funded by the Defichain Community:
Thank you for your trust! If you have suggestions for improvement
or other ideas open an [issue](https://github.com/eric-volz/DefichainPython/issues), 
write me on [Twitter](https://twitter.com/Intr0c) or via email (introc@volz.link)!

## [License & Disclaimer](https://docs.defichain-python.de/build/html/legal/licenseAndDisclaimer.html)

By using (this repo), you (the user) agree to be bound by the 
[terms of this license](https://github.com/eric-volz/defichainLibrary/blob/main/LICENSE) (MIT License).
